# My Sudoku
Sudoku generator and solver


## Installation
```
pip install mysudoku
```

Example:
```
from mysudoku import Sudoku

sudoku = Sudoku(dimension=3, difficulty=0.5)
sudoku.show()

'''
9 8 . 5 1 . . . .
. 6 . . . . 7 1 .
7 . 5 . 6 4 9 . .
. 2 . 7 5 . . . .
. . 4 9 . 6 . 5 .
8 5 . 4 3 1 6 2 .
. . 6 . 7 2 . 4 1
. 4 1 6 9 3 2 . .
. . 8 . 4 5 . 9 .
'''
```
